/*
 * File: YarnPattern.js
 * --------------------
 * This program uses the GLine class to simulate the process of winding a
 * piece of colored yarn around a set of pegs equally spaced along the
 * perimeter of a rectangle.  At each step, the yarn is stretched from
 * its current peg to the one DELTA pegs further on.
 */

/* Constants */

const N_ACROSS = 80;
const N_DOWN = 50;
const DELTA = 97;

/*
 * Creates a pattern that simulates the process of winding a piece of
 * yarn around an array of pegs along the edges of the canvas with the
 * id "canvas".
 */
function drawYarnPattern() {
   let canvas = document.getElementById("canvas");
   let ctx = canvas.getContext("2d");
   let pegs = createPegArray(canvas.width, canvas.height, N_ACROSS, N_DOWN);
   // complete the implementation here
}
 
/*
 * Creates a new Point object.  If this function is called with no
 * arguments, it creates a Point object at the origin.
 */
function Point(x, y) {
   if (x === undefined) { x = 0; y = 0; }
   return { x: x, y: y };
}

/*
 * Creates an array of pegs around the perimeter of a rectangle with the
 * specified width and height.  The number of pegs in each dimension is
 * given by the values nAcross and nDown.
 */
function createPegArray(width, height, nAcross, nDown) {
   let dx = width / nAcross;
   let dy = height / nDown;
   let pegs = [ ];
   for (let i = 0; i < nAcross; i++) {
      pegs.push(Point(i * dx, 0));
   }
   for (let i = 0; i < nDown; i++) {
      pegs.push(Point(nAcross * dx, i * dy));
   }
   for (let i = nAcross; i > 0; i--) {
      pegs.push(Point(i * dx, nDown * dy));
   }
   for (let i = nDown; i > 0; i--) {
      pegs.push(Point(0, i * dy));
   }
   return pegs;
}
